/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.util;

import java.io.File;
import java.io.FileFilter;
import java.io.IOException;
import org.openide.filesystems.FileObject;
import org.openide.util.Exceptions;

/**
 * 
 * @author Gerben Feenstra
 */
public class FileUtil {

    /**
     * Completely remove a directory and its content.
     * 
     * TODO: EXCEPTION HANDLING?
     * 
     * @param dir Directory to completely remove
     */
    public static void removeTree(File dir) {
        assert (dir != null);
        assert (dir.exists());

        // Find subdirs in specified dir
        File[] subdirs = dir.listFiles(new FileFilter() {

            @Override
            public boolean accept(File f) {
                if (f.isDirectory()) {
                    return true;
                }
                return false;
            }
        });

        // Recursive call to remove subdir and content
        for (File subdir : subdirs) {
            removeTree(subdir);
            subdir.delete();
        }

        // Find files in specified dir
        File[] files = dir.listFiles(new FileFilter() {

            @Override
            public boolean accept(File f) {
                if (f.isFile()) {
                    return true;
                }
                return false;
            }
        });

        // Remove files from dir
        for (File f : files) {
            f.delete();
        }

        // Remove the directory itself
        dir.delete();
    }

    /**
     * Retrieve and return the path of the current module
     * Creates and returns the real (full) path as File object of the module + specified path inside the module
     * 
     * @param packagePath For example: BeanTestUtils.getPath("/src/main/java");
     * @return For example: D:\projecten\agrosense~core\model\src\main\java
     */
    public static String getPath(String packagePath) {
        File currentpathFile = new File(".");
        String currentpathString = "";
        try {
            currentpathString = currentpathFile.getCanonicalPath();

        } catch (IOException ex) {
            Exceptions.printStackTrace(ex);
        }
        packagePath = "src.main.java." + packagePath;
        //nl.cloudfarming.client.model.Field
                

        return packagePath.replace('.', File.separatorChar);
    }
    
    /**
     * Touching file changes its lastModified date record.
     * <p>
     * Works only for existing files (not directories)
     * </p>
     * @param file
     * @return {@code true} if success, {@false} is touch failed.
     * 
     * 
     */
    public static boolean touch(File file) throws IOException {
        if (file != null && file.exists() && file.isFile()) {
            return file.setLastModified(System.currentTimeMillis());
        } else {
            return false;
        }
    }
    
    public static boolean touch(FileObject fileObject) throws IOException {
        return touch(org.openide.filesystems.FileUtil.toFile(fileObject));
    }
      
}
