/*
 * Copyright (c) 2012 AgroSense.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    AgroSense - initial API and implementation and/or initial documentation
 */
package nl.cloudfarming.client.util;

import java.awt.Color;
import java.util.HashMap;
import java.util.Map;
import java.util.NavigableMap;
import java.util.Objects;
import java.util.TreeMap;

/**
 *
 * @author johan
 */
public class Gradient {
    private final NavigableMap<Double, Color> stops;

    public Gradient(Map<Double, Color> stops) {
        this.stops = new TreeMap<>(stops);
    }

    public Color getColor(double position) {
        final double first = stops.firstKey(), last = stops.lastKey();
        if (position <= first) { return stops.get(first); }
        if (position >= last) { return stops.get(last); }
        final Map.Entry<Double, Color>  lo = stops.lowerEntry(position), hi = stops.ceilingEntry(position); // ceil: higher or equal
        final double fraction = (position - lo.getKey()) / (hi.getKey() - lo.getKey());
        return ColorUtil.interpolateRGBA(lo.getValue(), hi.getValue(), fraction);
    }

    @Override
    public int hashCode() {
        int hash = 5;
        hash = 59 * hash + Objects.hashCode(this.stops);
        return hash;
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Gradient other = (Gradient) obj;
        if (!Objects.equals(this.stops, other.stops)) {
            return false;
        }
        return true;
    }

    public static class Builder {
        private final Map<Double, Color> stops = new HashMap<>();

        public Builder stop(double  position, Color color) {
            assert position >= 0.0 && position <= 1.0 : "Position must be between 0.0 and 1.0 passed value " + position;
            assert color != null;
            stops.put(position, color);
            return this;
        }

        public Gradient build() {
            assert stops.size() > 0;
            return new Gradient(stops);
        }
    }

    public static void main(String[] args) {

        final Gradient g = new Builder()
                .stop(0.4, Color.red)
                .stop(0.75, Color.black)
                .stop(1.0, Color.yellow)
                .build();

        for (double d = 0.0; d <= 1.0; d += 1.0/8.0) {
            System.out.println(d + "\t" + g.getColor(d));
        }
    }
}
