/*
 * Copyright (c) 2012 AgroSense.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    AgroSense - initial API and implementation and/or initial documentation
 */
package nl.cloudfarming.client.util;

/**
 * Unit of measure.
 * 
 * @author johan
 */
public enum UOM {
    MM(Dimension.LENGTH, "mm"),
    CM(Dimension.LENGTH, "cm"),
    
    MM3_PER_M2(Dimension.VOLUME_PER_AREA, "mm3/m2"),
    L_PER_HA(Dimension.VOLUME_PER_AREA, "L/Ha"),
    
    MG_PER_M2(Dimension.MASS_PER_AREA, "mg/m2"),
    KG_PER_HA(Dimension.MASS_PER_AREA, "kg/Ha"),
    ;
    
    private Dimension dimension;
    private String label;

    private UOM(Dimension dimension, String label) {
        this.dimension = dimension;
        this.label = label;
    }

    public Dimension getDimension() {
        return dimension;
    }

    public String getLabel() {
        return label;
    }

    @Override
    public String toString() {
        return label;
    }
    
    
    
    // UOMs with the same dimension can be converted from one to the other.
    // TODO (low prio): set up conversion factor lookup.
    public enum Dimension {
        LENGTH,
        MASS_PER_AREA,
        VOLUME_PER_AREA,
        ;
    }
}
