/*
 *  Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 *  Licensed under the Eclipse Public License - v 1.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 * 
 *           http://www.eclipse.org/legal/epl-v10.html
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package nl.cloudfarming.client.util.actions;

import java.util.logging.Level;
import java.util.logging.Logger;
import org.openide.nodes.Node;
import org.openide.util.Lookup;

/**
 * Interface describing the capability to respond to something selected and or
 * deselected.
 * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
 */
public interface SelectDeselectHandler {
    
    /**
     * Handle object with provided context being selected.
     *
     * @param context
     */
    void select(Node context);

    /**
     * Handle object with provided context being deselected.
     *
     * @param context
     */
    void deselect(Node context);

    public static class Event {
        private static final Logger LOGGER = Logger.getLogger(SelectDeselectHandler.Event.class.getName());

        /**
         * Trigger an select event and signal all {@link SelectDeselectHandler#select(org.openide.nodes.Node)}
         * implementations
         * 
         * @param context 
         */
        public static void triggerSelect(Node context) {
            for (SelectDeselectHandler selectDeselectHandler : Lookup.getDefault().lookupAll(SelectDeselectHandler.class)) {
                try {
                    selectDeselectHandler.select(context);
                } catch (Exception ex) {
                    LOGGER.log(Level.WARNING, "FIXME:Ignored exception thrown from SelectDeselectHandler.select {0}", ex.getMessage());
                }
            }
        }
        
        /**
         * Trigger an deselect event and signal all {@link SelectDeselectHandler#deselect(org.openide.nodes.Node)}
         * implementations
         * 
         * @param context 
         */        
        public static void triggerDeselect(Node context) {
            for (SelectDeselectHandler selectDeselectHandler : Lookup.getDefault().lookupAll(SelectDeselectHandler.class)) {
                try {
                    selectDeselectHandler.deselect(context);
                } catch (Exception ex) {
                    LOGGER.log(Level.WARNING, "FIXME:Ignored exception thrown from SelectDeselectHandler.deselect {0}", ex.getMessage());
                }
            }
        }        
    }
    
}
